@@ -17,7 +17,8 @@ def save(gp: GP, model_name: str, directory: str = './'):
     if not model_name.endswith('.npz'):
         model_name += '.npz'
     objax.io.save_var_collection(f'{directory}{model_name}', gp.vars())
-    print(f"Model successfully saved to {directory} under filename {model_name}")
+    print(
+        f"Model successfully saved to {directory} under filename {model_name}")
 
 
 def load(gp: GP, location: str):
@@ -28,6 +29,7 @@ def load(gp: GP, location: str):
         gp: The GP for which the hyperparameters should be stored.
         location: The local filepath where the .npz file exists
     """
-    assert location.endswith('.npz'), "Loaded variables should be under a .npz extension"
+    assert location.endswith(
+        '.npz'), "Loaded variables should be under a .npz extension"
     objax.io.load_var_collection(location, gp.vars())
     return gp
